# MATER

Metabolic Analysis for Transdisciplinary Ecological Research

**See the official [documentation](https://isterre-dynamic-modeling.gricad-pages.univ-grenoble-alpes.fr/mater-project/mater/)**.
